pub struct ChromeBridge { /* private fields */ }Expand description
The live connection registry. One instance per process (see bridge).
Transport integration (in roder-app-server::remote), on each connection:
ⓘ
// on first `hello` frame:
let reg = bridge().register_client(Some(remote_addr.clone()), &frame);
// spawn a task draining reg.commands -> websocket as Message::Text(JSON)
// for every inbound bridge frame: bridge().ingest_frame(Some(reg.client_id), frame);
// on disconnect: bridge().unregister_client(reg.client_id);Implementations
Sourceimpl ChromeBridge
impl ChromeBridge
pub fn new() -> Self
Sourcepub fn register_client(
&self,
remote_addr: Option<String>,
hello: &Value,
) -> ChromeClientRegistration
pub fn register_client( &self, remote_addr: Option<String>, hello: &Value, ) -> ChromeClientRegistration
Register a newly-connected extension. Returns the receiver the transport must drain to deliver commands to that extension.
Sourcepub fn unregister_client(&self, client_id: u64)
pub fn unregister_client(&self, client_id: u64)
Remove a disconnected extension and fail any of its pending commands.
Sourcepub fn ingest_frame(&self, client_id: Option<u64>, frame: Value)
pub fn ingest_frame(&self, client_id: Option<u64>, frame: Value)
Route an inbound bridge frame from the extension: resolve a pending command result or fold an unsolicited event into bridge state.