pub struct ProcessInferenceEventNotification {
pub stream_id: String,
pub event: InferenceEvent,
}Expand description
inference/event notification payload (child -> host). The host routes
by stream_id and converts event into the runtime inference stream.
Fields
stream_id: Stringevent: InferenceEventTrait Implementations
Sourceimpl Clone for ProcessInferenceEventNotification
impl Clone for ProcessInferenceEventNotification
Sourcefn clone(&self) -> ProcessInferenceEventNotification
fn clone(&self) -> ProcessInferenceEventNotification
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ProcessInferenceEventNotification
impl<'de> Deserialize<'de> for ProcessInferenceEventNotification
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ProcessInferenceEventNotification
impl PartialEq for ProcessInferenceEventNotification
Sourcefn eq(&self, other: &ProcessInferenceEventNotification) -> bool
fn eq(&self, other: &ProcessInferenceEventNotification) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ProcessInferenceEventNotification