pub struct ProcessSubagentDispatchParams {
pub dispatcher_id: String,
pub dispatch_id: String,
pub parent_thread_id: ThreadId,
pub parent_turn_id: TurnId,
pub request: SubagentRequest,
}Expand description
subagents/dispatch params: a canonical request plus parent provenance
and a host-chosen dispatch id the child must echo and stream against.
Fields
dispatcher_id: Stringdispatch_id: Stringparent_thread_id: ThreadIdparent_turn_id: TurnIdrequest: SubagentRequestTrait Implementations
Sourceimpl Clone for ProcessSubagentDispatchParams
impl Clone for ProcessSubagentDispatchParams
Sourcefn clone(&self) -> ProcessSubagentDispatchParams
fn clone(&self) -> ProcessSubagentDispatchParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ProcessSubagentDispatchParams
impl<'de> Deserialize<'de> for ProcessSubagentDispatchParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ProcessSubagentDispatchParams
impl PartialEq for ProcessSubagentDispatchParams
Sourcefn eq(&self, other: &ProcessSubagentDispatchParams) -> bool
fn eq(&self, other: &ProcessSubagentDispatchParams) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ProcessSubagentDispatchParams