pub struct ProcessTaskExecuteParams {
pub executor_id: String,
pub execution_id: String,
pub task_id: String,
pub thread_id: Option<ThreadId>,
pub turn_id: Option<TurnId>,
pub workspace_root: Option<String>,
pub input: Value,
}Expand description
tasks/execute params: canonical task input plus execution provenance
and a host-chosen execution id the child must echo and stream against.
Fields
executor_id: Stringexecution_id: Stringtask_id: Stringthread_id: Option<ThreadId>turn_id: Option<TurnId>workspace_root: Option<String>input: ValueTrait Implementations
Sourceimpl Clone for ProcessTaskExecuteParams
impl Clone for ProcessTaskExecuteParams
Sourcefn clone(&self) -> ProcessTaskExecuteParams
fn clone(&self) -> ProcessTaskExecuteParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProcessTaskExecuteParams
impl Debug for ProcessTaskExecuteParams
Sourceimpl<'de> Deserialize<'de> for ProcessTaskExecuteParams
impl<'de> Deserialize<'de> for ProcessTaskExecuteParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ProcessTaskExecuteParams
impl PartialEq for ProcessTaskExecuteParams
Sourcefn eq(&self, other: &ProcessTaskExecuteParams) -> bool
fn eq(&self, other: &ProcessTaskExecuteParams) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ProcessTaskExecuteParams
impl Serialize for ProcessTaskExecuteParams
impl StructuralPartialEq for ProcessTaskExecuteParams