pub struct SubagentRequest {
pub description: String,
pub prompt: String,
pub subagent_type: Option<String>,
pub model: Option<String>,
pub provider: Option<String>,
pub tools: Option<Vec<String>>,
pub lane: Option<SubagentLane>,
pub max_concurrent: Option<usize>,
pub allowed_tools: Option<Vec<String>>,
pub parent_deadline_seconds: Option<u64>,
pub inputs: Option<Value>,
pub timeout_seconds: Option<u64>,
}Fields
description: Stringprompt: Stringsubagent_type: Option<String>model: Option<String>Optional model id. When omitted, the dispatcher prefers the parent thread’s live selection (when provided) over startup defaults.
provider: Option<String>Optional inference provider id (for example supergrok, codex).
When omitted with model, children inherit the parent thread provider
so task / agent_swarm stay on the same backend as the lead turn.
tools: Option<Vec<String>>lane: Option<SubagentLane>max_concurrent: Option<usize>allowed_tools: Option<Vec<String>>parent_deadline_seconds: Option<u64>inputs: Option<Value>timeout_seconds: Option<u64>Trait Implementations
Sourceimpl Clone for SubagentRequest
impl Clone for SubagentRequest
Sourceimpl Debug for SubagentRequest
impl Debug for SubagentRequest
Sourceimpl<'de> Deserialize<'de> for SubagentRequest
impl<'de> Deserialize<'de> for SubagentRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for SubagentRequest
impl PartialEq for SubagentRequest
Sourceimpl Serialize for SubagentRequest
impl Serialize for SubagentRequest
impl StructuralPartialEq for SubagentRequest