pub fn derive_package_id(source: &PackageSource) -> StringExpand description
Derives a fallback package id from the source when the manifest does not declare one (npm name tail, git repo name, or directory name).
pub fn derive_package_id(source: &PackageSource) -> StringDerives a fallback package id from the source when the manifest does not declare one (npm name tail, git repo name, or directory name).